---
id: 100
properties:
- id: priority
  name: testy
  type: string
  value: High
- id: done
  name: Done
  type: boolean
  value: false
- id: status
  name: Status
  type: status
  value: In Progress
---

# Buy groceries

- Milk
- Eggs
- Bread
- Coffee beans
- Avocados